# Changelog

All notable changes to this project will be documented in this file.

## [0.1.0] - 2025-10-23

### Added

- Initial release
- AWS SigV4 signed HTTP requests
- Automatic credential detection
- Convenience methods: `get`, `post`, `put`, `delete`, `patch`
- JSON helpers: `post_json`, `put_json`
- Retry decorator with exponential backoff
- Environment variable configuration
- Support for all AWS services including undocumented Console APIs
